import { BaseTexture } from "@pixi/core";
import { CubemapResource } from "./cubemap-resource";
import { Color } from "../color";
import { CubemapFaces } from "./cubemap-faces";
/**
 * Cubemap which supports multiple user specified mipmaps.
 */
export declare class Cubemap extends BaseTexture<CubemapResource> {
    /** Returns an array of faces. */
    static get faces(): ["posx", "negx", "posy", "negy", "posz", "negz"];
    /** Returns the number of mipmap levels. */
    get levels(): number;
    /**
     * Creates a new cubemap from the specified faces.
     * @param faces The faces to create the cubemap from.
     */
    static fromFaces(faces: CubemapFaces | CubemapFaces[]): Cubemap;
    /**
     * Creates a new cubemap from the specified colors.
     * @param posx The color for positive x.
     * @param negx The color for negative x.
     * @param posy The color for positive y.
     * @param negy The color for negative y.
     * @param posz The color for positive z.
     * @param negz The color for negative z.
     */
    static fromColors(posx: Color, negx?: Color, posy?: Color, negy?: Color, posz?: Color, negz?: Color): Cubemap;
}
