import { Renderer, IRendererPlugin } from "@pixi/core";
import { ImageBasedLighting } from "./image-based-lighting";
import { Light } from "./light";
/**
 * A lighting environment represents the different lighting conditions for a
 * specific object or an entire scene.
 */
export declare class LightingEnvironment implements IRendererPlugin {
    renderer: Renderer;
    /** The image-based lighting object. */
    imageBasedLighting?: ImageBasedLighting;
    /** The lights affecting this lighting environment. */
    lights: Light[];
    /** The main lighting environment which is used by default. */
    static main: LightingEnvironment;
    /**
     * Creates a new lighting environment using the specified renderer.
     * @param renderer The renderer to use.
     * @param imageBasedLighting The image based lighting to use.
     */
    constructor(renderer: Renderer, imageBasedLighting?: ImageBasedLighting);
    destroy(): void;
    /** Value indicating if this object is valid to be used for rendering. */
    get valid(): boolean;
}
